@@ -31,13 +31,13 @@
 #include <X11/StringDefs.h>
 #include <Xm/XmP.h>
 #include <Xm/Label.h>
+#include <Xbae/Macros.h>
 #include <Xbae/CaptionP.h>
 
-#ifndef SABER
-static char sccsid[] = "@(#)Caption.c	1.9 9/4/92";
+#ifndef tolower
+#define tolower(c)      ((c) - 'A' + 'a')
 #endif
 
-
 #define OffsetOf(field)	XtOffsetOf(XbaeCaptionRec, field)
 
 static XtResource resources[] = {
@@ -78,27 +78,52 @@ static XtResource resources[] = {
 /*
  * Declaration of methods
  */
-static void ClassInitialize();
-static void Initialize();
-static void InsertChild();
-static Boolean SetValues();
-static void SetValuesAlmost();
-static void GetValuesHook();
-static void Resize();
-static void ChangeManaged();
-static XtGeometryResult GeometryManager();
-static XtGeometryResult QueryGeometry();
+static void ClassInitialize P(( void ));
+static void Initialize P(( XbaeCaptionWidget request, XbaeCaptionWidget new,
+			   ArgList args, Cardinal *num_args ));
+static void InsertChild P(( Widget w ));
+static Boolean SetValues P(( XbaeCaptionWidget current,
+			     XbaeCaptionWidget request, XbaeCaptionWidget new,
+			     ArgList args, Cardinal *num_args ));
+static void SetValuesAlmost P(( XbaeCaptionWidget old, XbaeCaptionWidget new,
+				XtWidgetGeometry *request,
+				XtWidgetGeometry *reply ));
+static void GetValuesHook P(( XbaeCaptionWidget cw, ArgList args,
+			      Cardinal *num_args ));
+static void Resize P(( XbaeCaptionWidget cw ));
+static void ChangeManaged P(( XbaeCaptionWidget cw ));
+static XtGeometryResult GeometryManager P(( Widget w,
+					    XtWidgetGeometry *desired,
+					    XtWidgetGeometry *allowed ));
+static XtGeometryResult QueryGeometry P(( XbaeCaptionWidget cw,
+					  XtWidgetGeometry *proposed,
+					  XtWidgetGeometry *desired ));
 
 /*
  * Private functions
  */
-static void ComputeSize(), ComputeUserChildSize(), Layout();
-static Boolean CompareStrings();
+static void ComputeSize P(( XbaeCaptionWidget cw, Dimension *cwWidth,
+			    Dimension *cwHeight, Dimension childWidth,
+			    Dimension cHeight, Dimension cBorderWidth ));
+static void ComputeUserChildSize P(( XbaeCaptionWidget cw, Dimension cwWidth,
+				     Dimension cwHeight, Dimension *childWidth,
+				     Dimension *childHeight,
+				     Dimension childBorderWidth ));
+
+static void Layout P(( XbaeCaptionWidget cw, Boolean configure ));
+static Boolean CompareStrings P(( String in, String test ));
 
 /*
  * Type converters
  */
-static Boolean CvtStringToLabelPosition(), CvtStringToLabelAlignment();
+static Boolean CvtStringToLabelPosition P(( Display *dpy, XrmValuePtr args,
+					    Cardinal *num_args,
+					    XrmValuePtr from, XrmValuePtr to,
+					    XtPointer *data ));
+static Boolean CvtStringToLabelAlignment P(( Display *dpy, XrmValuePtr args,
+					     Cardinal *num_args,
+					     XrmValuePtr from, XrmValuePtr to,
+					     XtPointer *data ));
 
 
 XbaeCaptionClassRec xbaeCaptionClassRec = {
@@ -110,7 +135,7 @@ XbaeCaptionClassRec xbaeCaptionClassRec = {
 	/* class_initialize		*/ ClassInitialize,
 	/* class_part_initialize	*/ NULL,
 	/* class_inited			*/ False,
-	/* initialize			*/ Initialize,
+	/* initialize			*/ ( XtInitProc )Initialize,
 	/* initialize_hook		*/ NULL,
 	/* realize			*/ XtInheritRealize,
 	/* actions			*/ NULL,
@@ -123,24 +148,24 @@ XbaeCaptionClassRec xbaeCaptionClassRec = {
 	/* compress_enterleave		*/ True,
 	/* visible_interest		*/ False,
 	/* destroy			*/ NULL,
-	/* resize			*/ Resize,
+	/* resize			*/ ( XtWidgetProc )Resize,
 	/* expose			*/ _XmRedisplayGadgets,
-	/* set_values			*/ SetValues,
+	/* set_values			*/ ( XtSetValuesFunc )SetValues,
 	/* set_values_hook		*/ NULL,
-	/* set_values_almost		*/ SetValuesAlmost,
-	/* get_values_hook		*/ GetValuesHook,
+	/* set_values_almost		*/ ( XtAlmostProc )SetValuesAlmost,
+	/* get_values_hook		*/ ( XtArgsProc )GetValuesHook,
 	/* accept_focus			*/ NULL,
 	/* version			*/ XtVersion,
 	/* callback_private		*/ NULL,
 	/* tm_table			*/ XtInheritTranslations,
-	/* query_geometry		*/ QueryGeometry,
+	/* query_geometry		*/ ( XtGeometryHandler )QueryGeometry,
 	/* display_accelerator		*/ NULL,
 	/* extension			*/ NULL
     },
     {
     /* composite_class fields */
 	/* geometry_manager		*/ GeometryManager,
-	/* change_managed		*/ ChangeManaged,
+	/* change_managed		*/ ( XtWidgetProc )ChangeManaged,
 	/* insert_child			*/ InsertChild,
 	/* delete_child			*/ XtInheritDeleteChild,
 	/* extension			*/ NULL,
@@ -203,10 +228,11 @@ Cardinal *num_args;
     case XbaePositionBottom:
 	break;
     default:
-	XtAppWarningMsg(XtWidgetToApplicationContext((Widget)new),
-                        "initialize", "badLabelPosition", "XbaeCaption",
-                        "XbaeCaption: Invalid label position.",
-                        (String *) NULL, (Cardinal *) NULL);
+	XtAppWarningMsg(
+	    XtWidgetToApplicationContext((Widget)new),
+	    "initialize", "badLabelPosition", "XbaeCaption",
+	    "XbaeCaption: Invalid label position.",
+	    (String *) NULL, (Cardinal *) NULL);
 	new->caption.label_position = XbaePositionLeft;
 	break;
     }
@@ -220,10 +246,11 @@ Cardinal *num_args;
     case XbaeAlignmentBottomOrRight:
 	break;
     default:
-	XtAppWarningMsg(XtWidgetToApplicationContext((Widget)new),
-                        "initialize", "badLabelAlignment", "XbaeCaption",
-                        "XbaeCaption: Invalid label alignment.",
-                        (String *) NULL, (Cardinal *) NULL);
+	XtAppWarningMsg(
+	    XtWidgetToApplicationContext((Widget)new),
+	    "initialize", "badLabelAlignment", "XbaeCaption",
+	    "XbaeCaption: Invalid label alignment.",
+	    (String *) NULL, (Cardinal *) NULL);
 	new->caption.label_alignment = XbaeAlignmentCenter;
     }
 
@@ -233,7 +260,7 @@ Cardinal *num_args;
      * it will use our name as it's label.
      */
     (void)
-	XtVaCreateManagedWidget(XtName(new),
+	XtVaCreateManagedWidget(XtName((Widget)new),
 				xmLabelWidgetClass, (Widget)new,
 				XmNbackground,	new->core.background_pixel,
 				XmNforeground,	new->manager.foreground,
@@ -267,10 +294,11 @@ InsertChild(w)
 Widget w;
 {
     if (((CompositeWidget)XtParent(w))->composite.num_children > 1) {
-        XtAppWarningMsg(XtWidgetToApplicationContext(w),
-                        "insertChild", "badChild", "XbaeCaption",
-                        "XbaeCaption: Cannot add more than one child.",
-                        (String *)NULL, (Cardinal *)NULL);
+        XtAppWarningMsg(
+	    XtWidgetToApplicationContext(w),
+	    "insertChild", "badChild", "XbaeCaption",
+	    "XbaeCaption: Cannot add more than one child.",
+	    (String *)NULL, (Cardinal *)NULL);
         return;
     }
 
@@ -306,10 +334,11 @@ Cardinal *num_args;
 	case XbaePositionBottom:
 	    break;
 	default:
-	    XtAppWarningMsg(XtWidgetToApplicationContext((Widget)new),
-			    "setValues", "badLabelPosition", "XbaeCaption",
-			    "XbaeCaption: Invalid label position.",
-			    (String *) NULL, (Cardinal *) NULL);
+	    XtAppWarningMsg(
+		XtWidgetToApplicationContext((Widget)new),
+		"setValues", "badLabelPosition", "XbaeCaption",
+		"XbaeCaption: Invalid label position.",
+		(String *) NULL, (Cardinal *) NULL);
 	    new->caption.label_position = current->caption.label_position;
 	}
     }
@@ -324,10 +353,11 @@ Cardinal *num_args;
 	case XbaeAlignmentBottomOrRight:
 	    break;
 	default:
-	    XtAppWarningMsg(XtWidgetToApplicationContext((Widget)new),
-			    "setValues", "badLabelAlignment", "XbaeCaption",
-			    "XbaeCaption: Invalid label alignment.",
-			    (String *) NULL, (Cardinal *) NULL);
+	    XtAppWarningMsg(
+		XtWidgetToApplicationContext((Widget)new),
+		"setValues", "badLabelAlignment", "XbaeCaption",
+		"XbaeCaption: Invalid label alignment.",
+		(String *) NULL, (Cardinal *) NULL);
 	    new->caption.label_alignment = current->caption.label_alignment;
 	}
     }
@@ -474,12 +504,16 @@ Cardinal *num_args;
  * the initiating child (the label never initiates)
  */
 static void
+#if NeedFunctionPrototypes
+Layout(XbaeCaptionWidget cw, Boolean configure)
+#else
 Layout(cw, configure)
 XbaeCaptionWidget cw;
 Boolean configure;
+#endif
 {
-    Position label_x, label_y;
-    Position user_x, user_y;
+    Position label_x = 0, label_y = 0;
+    Position user_x = 0, user_y = 0;
     Dimension user_width, user_height;
 
     /*
@@ -596,13 +630,7 @@ Boolean configure;
 			     &user_width, &user_height,
 			     UserChild(cw)->core.border_width);
 
-	/*
-	 * Position and size the user's child.
-	 * XXX must use _XmConfigureObject instead of XtConfigureWidget
-	 * to handle gadgets (the Motif function always calls the gadgets
-	 * resize method)
-	 */
-	_XmConfigureObject((RectObj)UserChild(cw),
+	_XmConfigureObject((Widget)UserChild(cw),
 			   (int)user_x, (int)user_y,
 			   (int)user_width, (int)user_height,
 			   (int)UserChild(cw)->core.border_width);
@@ -621,6 +649,11 @@ XbaeCaptionWidget cw;
  * of the user's child, compute the width and height of the user's child.
  */
 static void
+#if NeedFunctionPrototypes
+ComputeUserChildSize(XbaeCaptionWidget cw, Dimension cwWidth,
+		     Dimension cwHeight, Dimension *childWidth,
+		     Dimension *childHeight, Dimension childBorderWidth )
+#else
 ComputeUserChildSize(cw, cwWidth, cwHeight, childWidth, childHeight,
 		     childBorderWidth)
 XbaeCaptionWidget cw;
@@ -629,6 +662,7 @@ Dimension cwHeight;
 Dimension *childWidth;
 Dimension *childHeight;
 Dimension childBorderWidth;
+#endif
 {
     int width = cwWidth - 2 * childBorderWidth;
     int height = cwHeight - 2 * childBorderWidth;
@@ -675,6 +709,11 @@ Dimension childBorderWidth;
  * current size of the label child)
  */
 static void
+#if NeedFunctionPrototypes
+ComputeSize(XbaeCaptionWidget cw, Dimension *cwWidth, Dimension *cwHeight,
+	    Dimension childWidth, Dimension childHeight,
+	    Dimension childBorderWidth)
+#else
 ComputeSize(cw, cwWidth, cwHeight, childWidth, childHeight, childBorderWidth)
 XbaeCaptionWidget cw;
 Dimension *cwWidth;
@@ -682,6 +721,7 @@ Dimension *cwHeight;
 Dimension childWidth;
 Dimension childHeight;
 Dimension childBorderWidth;
+#endif
 {
     childWidth += 2 * childBorderWidth;
     childHeight += 2 * childBorderWidth;
@@ -936,7 +976,7 @@ XtWidgetGeometry *proposed, *desired;
      */
     else {
 	XtWidgetGeometry childProposed, childDesired;
-	Dimension childWidth, childHeight, childBorderWidth;
+	Dimension childWidth, childHeight, childBorderWidth = 0;
 	Dimension cwWidth, cwHeight;
 	XtGeometryResult result;
 
@@ -981,7 +1021,8 @@ XtWidgetGeometry *proposed, *desired;
 	/*
 	 * Save the childs desired geometry.
 	 */
-	switch (result) {
+	switch (result)
+	{
 	case XtGeometryYes:
 	    /* use our computed childWidth and childHeight */
 	    childBorderWidth = UserChild(cw)->core.border_width;
@@ -996,6 +1037,8 @@ XtWidgetGeometry *proposed, *desired;
 	    childHeight = UserChild(cw)->core.height;
 	    childBorderWidth = UserChild(cw)->core.border_width;
 	    break;
+	default:
+	    break;
 	}
 
 	/*
@@ -1078,11 +1121,12 @@ XtPointer *data;
     static XbaeLabelPosition position;
 
     if (*num_args != 0)
-        XtAppWarningMsg(XtDisplayToApplicationContext(dpy),
-                        "cvtStringToLabelPosition", "wrongParameters",
-                        "XbaeCaption",
-                        "String to LabelPosition conversion needs no extra arguments",
-                        NULL, NULL);
+        XtAppWarningMsg(
+	    XtDisplayToApplicationContext(dpy),
+	    "cvtStringToLabelPosition", "wrongParameters",
+	    "XbaeCaption",
+	    "String to LabelPosition conversion needs no extra arguments",
+	    NULL, NULL);
 
     /*
      * User didn't provide enough space
@@ -1109,7 +1153,7 @@ XtPointer *data;
      * Store our return value
      */
     if (to->addr == NULL)
-        to->addr = (caddr_t) &position;
+        to->addr = (XtPointer) &position;
     else
         *(XbaeLabelPosition *) to->addr = position;
     to->size = sizeof(XbaeLabelPosition);
@@ -1129,11 +1173,12 @@ XtPointer *data;
     static XbaeLabelAlignment alignment;
 
     if (*num_args != 0)
-        XtAppWarningMsg(XtDisplayToApplicationContext(dpy),
-                        "cvtStringToLabelAlignment", "wrongParameters",
-                        "XbaeCaption",
-                        "String to LabelAlignment conversion needs no extra arguments",
-                        NULL, NULL);
+        XtAppWarningMsg(
+	    XtDisplayToApplicationContext(dpy),
+	    "cvtStringToLabelAlignment", "wrongParameters",
+	    "XbaeCaption",
+	    "String to LabelAlignment conversion needs no extra arguments",
+	    NULL, NULL);
 
     /*
      * User didn't provide enough space
@@ -1162,7 +1207,7 @@ XtPointer *data;
      * Store our return value
      */
     if (to->addr == NULL)
-        to->addr = (caddr_t) &alignment;
+        to->addr = (XtPointer) &alignment;
     else
         *(XbaeLabelAlignment *) to->addr = alignment;
     to->size = sizeof(XbaeLabelAlignment);
